@@ -24,9 +24,10 @@
 #' out3 = est.twonn(X3)
 #'
 #' ## print the results
-#' sprintf("* est.twonn : estimated dimension for 'swiss'  data is %.2f.",out1$estdim)
-#' sprintf("* est.twonn : estimated dimension for 'ribbon' data is %.2f.",out2$estdim)
-#' sprintf("* est.twonn : estimated dimension for 'saddle' data is %.2f.",out3$estdim)
+#' line1 = paste0("* est.twonn : 'swiss'  gives ",round(out1$estdim,2))
+#' line2 = paste0("* est.twonn : 'ribbon' gives ",round(out2$estdim,2))
+#' line3 = paste0("* est.twonn : 'saddle' gives ",round(out3$estdim,2))
+#' cat(paste0(line1,"\n",line2,"\n",line3))
 #' }
 #'
 #' @references
@@ -40,7 +41,7 @@ est.twonn <- function(X){
   ## Preprocessing and Default Parameter
   aux.typecheck(X)
   n = nrow(X)
-  D = as.matrix(dist(X))
+  D = as.matrix(stats::dist(X))
   diag(D) = Inf
 
   ##########################################################################
@@ -48,7 +49,7 @@ est.twonn <- function(X){
   #   1. compute the ratio
   mu = rep(0,n)
   for (i in 1:n){
-    tgt = sort(as.vector(D[i,]))[1:2]
+    tgt = sort(as.vector(D[i,]), decreasing = FALSE)[1:2]
     mu[i] = tgt[2]/tgt[1]
   }
   #   2. transform
@@ -58,9 +59,13 @@ est.twonn <- function(X){
   x = log(mu.sorted)[1:(n-1)]
   y = -log(1.0-empiF)
 
+  idsave = (!is.infinite(x))
+  x = x[idsave]
+  y = y[idsave]
+
   ##########################################################################
   ## Return the results
   result = list()
-  result$estdim = sum(coefficients(lm(y~x-1))[1])
+  result$estdim = sum(coefficients(stats::lm(y~x-1))[1])
   return(result)
 }
