@@ -3,41 +3,41 @@
 #' Nonnegative Principal Component Analysis (NPCA) is a variant of PCA where
 #' projection vectors - or, basis for learned subspace - contain no negative values.
 #'
-#' @param X an \eqn{(n\times p)} matrix or data frame whose rows are observations.
+#' @param X an \eqn{(n\times p)} matrix whose rows are observations
+#' and columns represent independent variables.
 #' @param ndim an integer-valued target dimension.
-#' @param preprocess an additional option for preprocessing the data.
-#' Default is "center". See also \code{\link{aux.preprocess}} for more details.
-#' @param maxiter number of maximum iteraions allowed.
-#' @param reltol stopping criterion for incremental relative error.
-#'
-#' @return a named list containing
-#' \describe{
-#' \item{Y}{an \eqn{(n\times ndim)} matrix whose rows are embedded observations.}
-#' \item{trfinfo}{a list containing information for out-of-sample prediction.}
-#' \item{projection}{a \eqn{(p\times ndim)} whose columns are basis for projection.}
+#' @param ... extra parameters including \describe{
+#' \item{maxiter}{maximum number of iterations (default: 100).}
+#' \item{reltol}{relative tolerance stopping criterion (default: 1e-4).}
 #' }
 #'
+#' @return a named \code{Rdimtools} S3 object containing
+#' \describe{
+#' \item{Y}{an \eqn{(n\times ndim)} matrix whose rows are embedded observations.}
+#' \item{projection}{a \eqn{(p\times ndim)} whose columns are basis for projection.}
+#' \item{algorithm}{name of the algorithm.}
+#' }
 #'
 #' @examples
 #' \dontrun{
 #' ## use iris data
-#' data(iris)
+#' data(iris, package="Rdimtools")
 #' set.seed(100)
 #' subid = sample(1:150, 50)
 #' X     = as.matrix(iris[subid,1:4]) + 50
 #' label = as.factor(iris[subid,5])
 #'
-#' ## use different preprocessing
-#' out1 = do.npca(X, preprocess="center")
-#' out2 = do.npca(X, preprocess="cscale")
-#' out3 = do.npca(X, preprocess="whiten")
+#' ## run NCPA and compare with others
+#' outNPC = do.npca(X)
+#' outPCA = do.pca(X)
+#' outMVP = do.mvp(X, label)
 #'
 #' ## visualize
 #' opar <- par(no.readonly=TRUE)
 #' par(mfrow=c(1,3))
-#' plot(out1$Y, pch=19, col=label, main="NPCA:: center")
-#' plot(out2$Y, pch=19, col=label, main="NPCA:: cscale")
-#' plot(out3$Y, pch=19, col=label, main="NPCA:: whiten")
+#' plot(outNPC$Y, pch=19, col=label, main="NPCA")
+#' plot(outPCA$Y, pch=19, col=label, main="PCA")
+#' plot(outMVP$Y, pch=19, col=label, main="MVP")
 #' par(opar)
 #' }
 #'
@@ -49,8 +49,7 @@
 #' @author Kisung You
 #' @concept linear_methods
 #' @export
-do.npca <- function(X, ndim=2, preprocess=c("center","scale","cscale","decorrelate","whiten"),
-                    maxiter=1000, reltol=1e-5){
+do.npca <- function(X, ndim=2, ...){
   #------------------------------------------------------------------------
   ## PREPROCESSING
   #   1. data matrix
@@ -61,28 +60,39 @@ do.npca <- function(X, ndim=2, preprocess=c("center","scale","cscale","decorrela
   ndim = as.integer(ndim)
   if (!check_ndim(ndim,p)){stop("* do.npca : 'ndim' is a positive integer in [1,#(covariates)).")}
   #   3. preprocess
-  if (missing(preprocess)){
-    algpreprocess = "center"
-  } else {
-    algpreprocess = match.arg(preprocess)
-  }
+  # if (missing(preprocess)){
+  #   algpreprocess = "center"
+  # } else {
+  #   algpreprocess = match.arg(preprocess)
+  # }
   #   * maxiter and reltol
-  maxiter = as.integer(maxiter)
-  if (!check_NumMM(maxiter, 5, 1e+6)){stop("* do.npca : 'maxiter' is a large positive integer for the number of iterations.")}
-  reltol = as.double(reltol)
-  if (!check_NumMM(reltol, .Machine$double.eps, 1)){stop("* do.npca : 'reltol' is a small positive real number for stopping criterion.")}
+
+  # Extra parameters
+  params  = list(...)
+  pnames  = names(params)
+
+  if ("reltol"%in%pnames){
+    reltol = max(.Machine$double.eps, as.double(params$reltol))
+  } else {
+    reltol = 10^(-4)
+  }
+  if ("maxiter"%in%pnames){
+    maxiter = max(5, round(params$maxiter))
+  } else {
+    maxiter = 100
+  }
 
   #------------------------------------------------------------------------
   ## COMPUTATION : DATA PREPROCESSING
-  tmplist = aux.preprocess.hidden(X,type=algpreprocess,algtype="linear")
-  trfinfo = tmplist$info
-  pX      = tmplist$pX
+  # tmplist = aux.preprocess.hidden(X,type=algpreprocess,algtype="linear")
+  # trfinfo = tmplist$info
+  # pX      = tmplist$pX
   #------------------------------------------------------------------------
   ## COMPUTATION : MAIN PART FOR NONNEGATIVE PCA
   #   1. initialize for U
   Uinit = matrix(runif(p*ndim),nrow=p)
   #   2. compute C
-  C = cov(pX)
+  C = stats::cov(X)
   #   3. compute projection matrix
   projection = method_nnprojmax(C, Uinit, reltol, maxiter)
   #   4. additional step : NA
@@ -96,8 +106,8 @@ do.npca <- function(X, ndim=2, preprocess=c("center","scale","cscale","decorrela
   #------------------------------------------------------------------------
   ## RETURN
   result = list()
-  result$Y = pX%*%projection
-  result$trfinfo = trfinfo
+  result$Y = X%*%projection
   result$projection = projection
-  return(result)
+  result$algorithm  = "linear:NPCA"
+  return(structure(result, class="Rdimtools"))
 }
