@@ -17,6 +17,7 @@
  *    v2aux_knn      : return the index of k-nearest neighbors
  *    v2aux_fid2proj : replicate 'aux.featureindicator' function
  *    v2aux_pagerank : page rank algorithm
+ *    v2aux_pdist2   : cross pairwise distance
  */
 
 // Part 1. Methods Related
@@ -31,5 +32,6 @@ arma::mat  v2aux_solproj(arma::mat& LHS, arma::mat& RHS);
 arma::umat v2aux_knn(arma::mat& X, int k);
 arma::mat  v2aux_fid2proj(int p, int ndim, arma::uvec idxvec);
 arma::vec  v2aux_pagerank(arma::mat& A);
+arma::mat  v2aux_pdist2(arma::mat &X, arma::mat &Y);
 
 #endif
